@@ -1,38 +1,6 @@
-/****************************************************************************
-**
-** Copyright (C) 2017 Andre Hartmann <aha_1980@gmx.de>
-** Contact: http://www.qt.io/licensing/
-**
-** This file is part of the QtSerialBus module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL3$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPLv3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or later as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file. Please review the following information to
-** ensure the GNU General Public License version 2.0 requirements will be
-** met: http://www.gnu.org/licenses/gpl-2.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2017 Andre Hartmann <aha_1980@gmx.de>
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:default
 
 #ifndef SYSTECCAN_SYMBOLS_P_H
 #define SYSTECCAN_SYMBOLS_P_H
@@ -81,6 +49,20 @@ typedef void (DRV_CALLBACK_TYPE *tCallbackFktEx) (tUcanHandle handle, quint32 ev
 #define USBCAN_EVENT_FATALDISCON            8    // a USB-CANmodul has been disconnected during operation
 #define USBCAN_EVENT_RESERVED1              0x80
 
+// CAN status flags (is returned with function UcanGetStatus() or UcanGetStatusEx() )
+#define USBCAN_CANERR_OK                    0x0000 // no error
+#define USBCAN_CANERR_XMTFULL               0x0001 // Tx-buffer of the CAN controller is full
+#define USBCAN_CANERR_OVERRUN               0x0002 // Rx-buffer of the CAN controller is full
+#define USBCAN_CANERR_BUSLIGHT              0x0004 // Bus error: Error Limit 1 exceeded (refer to SJA1000 manual)
+#define USBCAN_CANERR_BUSHEAVY              0x0008 // Bus error: Error Limit 2 exceeded (refer to SJA1000 manual)
+#define USBCAN_CANERR_BUSOFF                0x0010 // Bus error: CAN controller has gone into Bus-Off state
+#define USBCAN_CANERR_QRCVEMPTY             0x0020 // RcvQueue is empty
+#define USBCAN_CANERR_QOVERRUN              0x0040 // RcvQueue overrun
+#define USBCAN_CANERR_QXMTFULL              0x0080 // transmit queue is full
+#define USBCAN_CANERR_REGTEST               0x0100 // Register test of the SJA1000 failed
+#define USBCAN_CANERR_MEMTEST               0x0200 // Memory test failed
+#define USBCAN_CANERR_TXMSGLOST             0x0400 // transmit CAN message was automatically deleted by firmware
+
 #define kUcanModeNormal         0x00        // normal mode (send and receive)
 #define kUcanModeListenOnly     0x01        // listen only mode (only receive)
 #define kUcanModeTxEcho         0x02        // CAN messages which was sent will be received at UcanReadCanMsg..
@@ -88,8 +70,8 @@ typedef void (DRV_CALLBACK_TYPE *tCallbackFktEx) (tUcanHandle handle, quint32 ev
 #define kUcanModeHighResTimer   0x08        // high resolution time stamps in received CAN messages (only available with STM derivates)
 
 // ABR and ACR for mode "receive all CAN messages"
-#define USBCAN_AMR_ALL                      (quint32) 0xffffffff
-#define USBCAN_ACR_ALL                      (quint32) 0x00000000
+#define USBCAN_AMR_ALL                      0xffffffffU
+#define USBCAN_ACR_ALL                      0x00000000U
 
 #define USBCAN_OCR_DEFAULT                  0x1A  // default OCR for standard GW-002
 #define USBCAN_OCR_RS485_ISOLATED           0x1E  // OCR for RS485 interface and galvanic isolation
@@ -143,6 +125,11 @@ typedef struct _tCanMsgStruct {
     quint32 m_dwTime;                       // Time in ms
 } tCanMsgStruct;
 
+typedef struct _tStatusStruct {
+    quint16 m_wCanStatus;                   // current CAN status
+    quint16 m_wUsbStatus;                   // current USB status
+} tStatusStruct;
+
 // Function return codes (encoding)
 #define USBCAN_SUCCESSFUL                   0x00                // no error
 #define USBCAN_ERR                          0x01                // error in library; function has not been executed
@@ -280,7 +267,11 @@ GENERATE_SYMBOL_VARIABLE(UCANRET, UcanDeinitHardware, tUcanHandle)
 GENERATE_SYMBOL_VARIABLE(UCANRET, UcanInitCanEx2, tUcanHandle, quint8 /* channel */, tUcanInitCanParam *)
 GENERATE_SYMBOL_VARIABLE(UCANRET, UcanDeinitCanEx, tUcanHandle, quint8 /* channel */)
 GENERATE_SYMBOL_VARIABLE(UCANRET, UcanReadCanMsgEx, tUcanHandle, quint8 *, tCanMsgStruct *, quint32 *)
+GENERATE_SYMBOL_VARIABLE(UCANRET, UcanResetCan, tUcanHandle)
 GENERATE_SYMBOL_VARIABLE(UCANRET, UcanWriteCanMsgEx, tUcanHandle, quint8, tCanMsgStruct *, quint32 *)
+GENERATE_SYMBOL_VARIABLE(UCANRET, UcanGetStatus, tUcanHandle, tStatusStruct *)
+GENERATE_SYMBOL_VARIABLE(UCANRET, UcanGetHardwareInfoEx2, tUcanHandle, tUcanHardwareInfoEx *,
+                         void * /* channelInfo0 */, void * /* channelInfo1 */);
 
 inline bool resolveSystecCanSymbols(QLibrary *systecLibrary)
 {
@@ -300,7 +291,10 @@ inline bool resolveSystecCanSymbols(QLibrary *systecLibrary)
     RESOLVE_SYMBOL(UcanInitCanEx2);
     RESOLVE_SYMBOL(UcanDeinitCanEx);
     RESOLVE_SYMBOL(UcanReadCanMsgEx);
+    RESOLVE_SYMBOL(UcanResetCan);
     RESOLVE_SYMBOL(UcanWriteCanMsgEx);
+    RESOLVE_SYMBOL(UcanGetStatus);
+    RESOLVE_SYMBOL(UcanGetHardwareInfoEx2);
 
     return true;
 }
